@@ -228,3 +228,22 @@ retry_transfer <- function(res)
         !grepl("Could not resolve host", res$message, fixed=TRUE)
 }
 
+
+delete_confirmed <- function(confirm, name, type)
+{
+    if(!interactive() || !confirm)
+        return(TRUE)
+
+    msg <- sprintf("Are you sure you really want to delete the %s '%s'?", type, name)
+
+    ok <- if(getRversion() < numeric_version("3.5.0"))
+    {
+        msg <- paste(msg, "(yes/No/cancel) ")
+        yn <- readline(msg)
+        if(nchar(yn) == 0)
+            FALSE
+        else tolower(substr(yn, 1, 1)) == "y"
+    }
+    else utils::askYesNo(msg, FALSE)
+    isTRUE(ok)
+}
